@@ -12,70 +12,6 @@ pub struct Ellipsoid {
     f: f64,
 }
 
-/// Overrepresentation of an ellipsoid: Precompute additional useful constants.
-#[allow(non_snake_case)]
-#[derive(Clone, Copy, Debug)]
-pub struct FatEllipsoid {
-    // Axes
-    pub a: f64, // Semimajor axis
-    ay: f64,    // Equatoreal semiminor axis
-    b: f64,     // Semiminor axis
-    ra: f64,    // 1 / a
-    ray: f64,   // 1 / ay
-    rb: f64,    // 1 / b
-
-    // Flattenings
-    f: f64,
-    fe: f64, // Equatoreal flattening (0 for biaxial)
-    g: f64,  // Second flattening
-    n: f64,  // Third flattening
-    rf: f64, // 1 / f
-    rn: f64, // 1 / n
-    ar: f64, // Aspect ratio: 1 - f = b / a
-
-    // Eccentricities
-    e: f64,       // Eccentricity
-    ee: f64,      // Equatoreal eccentricity (0 for biaxial)
-    es: f64,      // Eccentricity squared
-    ees: f64,     // Equatoreal eccentricity squared
-    e4: f64,      // Eccentricity squared, squared
-    ep: f64,      // Second eccentricity
-    eps: f64,     // Second eccentricity squared
-    E: f64,       // Linear eccentricity
-    one_es: f64,  // 1 - es
-    rone_es: f64, // 1 / one_es
-}
-
-#[allow(non_snake_case)]
-#[derive(Clone, Copy, Debug)]
-pub(crate) struct CartographicFoundations {
-    lat_0: f64,
-    lat_1: f64,
-    lat_2: f64,
-    lat_3: f64,
-    lat_4: f64,
-
-    lon_0: f64,
-    lon_1: f64,
-    lon_2: f64,
-    lon_3: f64,
-    lon_4: f64,
-
-    N0: f64,
-    N1: f64,
-    N2: f64,
-    N3: f64,
-    N4: f64,
-
-    E0: f64,
-    E1: f64,
-    E2: f64,
-    E3: f64,
-    E4: f64,
-
-    k_0: f64,
-}
-
 /// GRS80 is the default ellipsoid.
 impl Default for Ellipsoid {
     fn default() -> Ellipsoid {
@@ -83,78 +19,6 @@ impl Default for Ellipsoid {
     }
 }
 
-pub trait Axes {
-    fn a(&self) -> f64;
-    fn ay(&self) -> f64;
-    fn f(&self) -> f64;
-
-    /// The semimajor axis, *a*
-    #[must_use]
-    fn semimajor_axis(&self) -> f64 {
-        self.a()
-    }
-
-    /// The semimedian axis, *ay*
-    #[must_use]
-    fn semimedian_axis(&self) -> f64 {
-        self.ay()
-    }
-
-    /// The semiminor axis, *b*
-    #[must_use]
-    fn semiminor_axis(&self) -> f64 {
-        self.a() * (1.0 - self.f())
-    }
-}
-
-impl Axes for Ellipsoid {
-    fn a(&self) -> f64 {
-        self.a
-    }
-    fn ay(&self) -> f64 {
-        self.ay
-    }
-    fn f(&self) -> f64 {
-        self.f
-    }
-}
-
-impl Axes for FatEllipsoid {
-    fn a(&self) -> f64 {
-        self.a
-    }
-    fn ay(&self) -> f64 {
-        self.ay
-    }
-    fn f(&self) -> f64 {
-        self.f
-    }
-}
-
-pub trait Axen<T> {
-    fn a(&self) -> f64;
-    fn ay(&self) -> f64;
-    fn f(&self) -> f64;
-
-    /// The semimajor axis, *a*
-    #[must_use]
-    fn semimajor_axis(&self) -> f64 {
-        self.a()
-    }
-
-    /// The semimedian axis, *ay*
-    #[must_use]
-    fn semimedian_axis(&self) -> f64 {
-        self.ay()
-    }
-
-    /// The semiminor axis, *b*
-    #[must_use]
-    fn semiminor_axis(&self) -> f64 {
-        self.a() * (1.0 - self.f())
-    }
-}
-
 impl Ellipsoid {
     /// User defined ellipsoid
     #[must_use]
