@@ -154,7 +154,8 @@ impl OperatorCore for Tmerc {
 mod tests {
     #[test]
     fn utm() {
-        use crate::{Context, CoordinateTuple, Ellipsoid, Operator, OperatorCore};
+        use crate::operator_construction::*;
+        use crate::{Context, CoordinateTuple, Ellipsoid};
 
         let mut ctx = Context::new();
 
@@ -207,6 +208,7 @@ mod tests {
 
     #[test]
     fn tmerc() {
+        use crate::operator_construction::*;
         use crate::*;
         let mut ctx = Context::new();
 
